# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.15
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UpstreamGroupMappingSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upstream_issuer': 'str',
        'org_id': 'str',
        'group_mappings': 'list[UpstreamGroupMappingEntry]',
        'excluded_groups': 'list[UpstreamGroupExcludedEntry]'
    }

    attribute_map = {
        'upstream_issuer': 'upstream_issuer',
        'org_id': 'org_id',
        'group_mappings': 'group_mappings',
        'excluded_groups': 'excluded_groups'
    }

    def __init__(self, upstream_issuer=None, org_id=None, group_mappings=None, excluded_groups=None, local_vars_configuration=None):  # noqa: E501
        """UpstreamGroupMappingSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._upstream_issuer = None
        self._org_id = None
        self._group_mappings = None
        self._excluded_groups = None
        self.discriminator = None

        self.upstream_issuer = upstream_issuer
        self.org_id = org_id
        if group_mappings is not None:
            self.group_mappings = group_mappings
        if excluded_groups is not None:
            self.excluded_groups = excluded_groups

    @property
    def upstream_issuer(self):
        """Gets the upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501

        the upstream issuer that this mapping pertains to  # noqa: E501

        :return: The upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: str
        """
        return self._upstream_issuer

    @upstream_issuer.setter
    def upstream_issuer(self, upstream_issuer):
        """Sets the upstream_issuer of this UpstreamGroupMappingSpec.

        the upstream issuer that this mapping pertains to  # noqa: E501

        :param upstream_issuer: The upstream_issuer of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and upstream_issuer is None:  # noqa: E501
            raise ValueError("Invalid value for `upstream_issuer`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                upstream_issuer is not None and len(upstream_issuer) > 100):
            raise ValueError("Invalid value for `upstream_issuer`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                upstream_issuer is not None and len(upstream_issuer) < 1):
            raise ValueError("Invalid value for `upstream_issuer`, length must be greater than or equal to `1`")  # noqa: E501

        self._upstream_issuer = upstream_issuer

    @property
    def org_id(self):
        """Gets the org_id of this UpstreamGroupMappingSpec.  # noqa: E501

        The org id corresponding to the issuer whose mapping is being updated  # noqa: E501

        :return: The org_id of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this UpstreamGroupMappingSpec.

        The org id corresponding to the issuer whose mapping is being updated  # noqa: E501

        :param org_id: The org_id of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def group_mappings(self):
        """Gets the group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501

        The list of upstream group mappings  # noqa: E501

        :return: The group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: list[UpstreamGroupMappingEntry]
        """
        return self._group_mappings

    @group_mappings.setter
    def group_mappings(self, group_mappings):
        """Sets the group_mappings of this UpstreamGroupMappingSpec.

        The list of upstream group mappings  # noqa: E501

        :param group_mappings: The group_mappings of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: list[UpstreamGroupMappingEntry]
        """

        self._group_mappings = group_mappings

    @property
    def excluded_groups(self):
        """Gets the excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501

        The list of upstream groups you wish to explicitly exclude from mapping. This is useful for a wildcard mapping   # noqa: E501

        :return: The excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501
        :rtype: list[UpstreamGroupExcludedEntry]
        """
        return self._excluded_groups

    @excluded_groups.setter
    def excluded_groups(self, excluded_groups):
        """Sets the excluded_groups of this UpstreamGroupMappingSpec.

        The list of upstream groups you wish to explicitly exclude from mapping. This is useful for a wildcard mapping   # noqa: E501

        :param excluded_groups: The excluded_groups of this UpstreamGroupMappingSpec.  # noqa: E501
        :type: list[UpstreamGroupExcludedEntry]
        """

        self._excluded_groups = excluded_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpstreamGroupMappingSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpstreamGroupMappingSpec):
            return True

        return self.to_dict() != other.to_dict()
